==> taktile-cli-0.2.26.tar.gz: taktile-cli-0.2.26/tktl/commands/health.py <==
import requests
from pyarrow._flight import FlightCancelledError
from pyarrow.flight import FlightClient

from tktl.commands import BaseGrpcClientCommand, BaseRestClientCommand
from tktl.core.clients import API
from tktl.core.exceptions.exceptions import APIClientException


class GetRestHealthCommand(BaseRestClientCommand):
    def execute(self):
        if self.client.local:
            self.client.set_client_and_location(
                location=self.client.local_endpoint,
                client=API(api_url=self.client.local_endpoint),
            )
        else:
            self.client.authenticate(health_check=True)
        try:
            response = self.client.health()
        except APIClientException as e:
            error_str = f"Service is not running properly: {repr(e.detail)}"
            self.client.logger.error(error_str)
            raise APIClientException(detail=error_str, status_code=e.status_code)
        except requests.exceptions.RequestException as e:
            error_str = f"Unable to decode server response: {repr(e)}"
            self.client.logger.error(error_str)
            raise APIClientException(detail=error_str, status_code=400)
        if response.status_code < 400:
            self.client.logger.log(
                f"Service at {self.client.location} is up and running", color="green"
            )
            return response


class GetGrpcHealthCommand(BaseGrpcClientCommand):
    def execute(self):
        if self.client.local:
            self.client.set_client_and_location(
                location=self.client.local_endpoint,
                client=FlightClient(location=self.client.local_endpoint),
            )
        else:
            try:
                self.client.authenticate(health_check=True)
            except FlightCancelledError as e:
                error_str = f"Service is not running properly: {repr(e)}"
                self.client.logger.error(error_str)
                raise APIClientException(detail=error_str, status_code=404)
        try:
            response = self.client.health()
        except APIClientException as e:
            error_str = f"Service is not running properly: {repr(e.detail)}"
            self.client.logger.error(error_str)

            raise APIClientException(detail=error_str, status_code=e.status_code)

        self.client.logger.log(
            f"Service at {self.client.location} is up and running", color="green"
        )
        return response

==> taktile-cli-0.3.10.tar.gz: taktile-cli-0.3.10/tktl/commands/health.py <==
import requests
from pyarrow._flight import FlightCancelledError
from pyarrow.flight import FlightClient

from tktl.commands import BaseGrpcClientCommand, BaseRestClientCommand
from tktl.core.clients import API
from tktl.core.exceptions.exceptions import APIClientException


class GetRestHealthCommand(BaseRestClientCommand):
    def execute(self, endpoint_name: str):
        if self.client.local:
            self.client.set_client_and_location(
                location=self.client.local_endpoint,
                client=API(api_url=self.client.local_endpoint),
            )
        else:
            self.client.authenticate(endpoint_name=endpoint_name)
        try:
            response = self.client.health()
        except APIClientException as e:
            error_str = f"Service is not running properly: {repr(e.detail)}"
            self.client.logger.error(error_str)
            raise APIClientException(detail=error_str, status_code=e.status_code)
        except requests.exceptions.RequestException as e:
            error_str = f"Unable to decode server response: {repr(e)}"
            self.client.logger.error(error_str)
            raise APIClientException(detail=error_str, status_code=400)
        if response.status_code < 400:
            self.client.logger.log(
                f"Service at {self.client.location} is up and running", color="green"
            )
            return response


class GetGrpcHealthCommand(BaseGrpcClientCommand):
    def execute(self, endpoint_name: str):
        if self.client.local:
            self.client.set_client_and_location(
                location=self.client.local_endpoint,
                client=FlightClient(location=self.client.local_endpoint),
            )
        else:
            try:
                self.client.authenticate(endpoint_name=endpoint_name)
            except FlightCancelledError as e:
                error_str = f"Service is not running properly: {repr(e)}"
                self.client.logger.error(error_str)
                raise APIClientException(detail=error_str, status_code=404)
        try:
            response = self.client.health()
        except APIClientException as e:
            error_str = f"Service is not running properly: {repr(e.detail)}"
            self.client.logger.error(error_str)
            raise APIClientException(detail=error_str, status_code=e.status_code)
        self.client.logger.log(
            f"Service at {self.client.location} is up and running", color="green"
        )
        return response
